import org.odmg.Database;
import org.odmg.ODMGException;
import org.odmg.OQLQuery;
import org.odmg.Transaction;

import rasj.RasException;
import rasj.RasImplementation;
import rasj.RasMArrayShort;
import rasj.RasMInterval;

public class MemFill {
	private static String server = "localhost";
	private static String port = "7001";
	private static String base = "RASBASE";
	private static String user = "rasadmin";
	private static String password = "rasadmin";

	private static int getIndex(int cols, int row, int col) {
		return (row * cols) + col;
	}

	public static void main(String[] args) {
		Database database = null;
		Transaction transaction = null;
		try {
			RasImplementation app = new RasImplementation("http://" + server + ":" + port);
			app.setUserIdentification(user, password);

			database = app.newDatabase();
			database.open(base, Database.OPEN_READ_WRITE);

			int minRow = 0;
			int maxRow = 900;
			int minCol = 0;
			int maxCol = 900;
			short value = 0;
			short[] rawData = new short[maxRow * maxCol];
			for (int row = minRow; row < maxRow; row++) {
				for (int col = minCol; col < maxCol; col++) {
					rawData[getIndex(maxCol, row, col)] = value;
					value = (short) (value + 1);
				}
			}

			for (int day = 1; day <= 31; day++) {
				for (int hour = 0; hour <= 23; hour++) {
					System.out.println("Update data for day=" + day + " hour=" + hour);

					transaction = app.newTransaction();
					transaction.begin();

					String interval = String.format("[%d:%d, %d:%d]", minRow, maxRow - 1, minCol, maxCol - 1);
					RasMArrayShort data = new RasMArrayShort(new RasMInterval(interval));
					data.setObjectTypeName("MemTest");
					data.setArray(rawData);

					OQLQuery updateQuery = app.newOQLQuery();
					updateQuery.create("update MemTestData as c set c[$1, $2, $3, $4, $5, *:*, *:*] assign $6");
					updateQuery.bind(2016);
					updateQuery.bind(12);
					updateQuery.bind(day);
					updateQuery.bind(hour);
					updateQuery.bind(0);
					updateQuery.bind(data);
					updateQuery.execute();

					transaction.commit();
				}
			}
		} catch (ODMGException e) {
			e.printStackTrace();
			if (transaction != null) {
				transaction.abort();
			}
		} catch (RasException e) {
			e.printStackTrace();
		} finally {
			if (database != null) {
				try {
					database.close();
				} catch (ODMGException e) {
					e.printStackTrace();
				}
			}
		}
	}
}
